==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ru.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Хранилище временно недоступно",
    "Storage invalid" : "Хранилище неисправно",
    "Unknown error" : "Неизвестная ошибка",
    "All files" : "Все файлы",
    "Recent" : "Недавно изменённые",
    "Favorites" : "Избранные",
    "File could not be found" : "Невозможно найти файл",
    "Move or copy" : "Переместить или копировать",
    "Download" : "Скачать",
    "Delete" : "Удалить",
    "Home" : "Главная",
    "Close" : "Закрыть",
    "Could not create folder \"{dir}\"" : "Невозможно создать каталог «{dir}»",
    "This will stop your current uploads." : "Это действие остановит активные сеансы передачи файлов на сервер. ",
    "Upload cancelled." : "Выгрузка отменена.",
    "Processing files …" : "Обработка файлов…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Невозможно загрузить «{filename}», так как это либо каталог, либо файл нулевого размера",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостаточно свободного места, вы передаёте на сервер {size1}, но доступно только {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Целевой каталог «{dir}» более не существует",
    "Not enough free space" : "Недостаточно свободного места",
    "An unknown error has occurred" : "Произошла неизвестная ошибка",
    "Uploading …" : "Загрузка…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} из {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Загрузка этого элемента не поддерживается",
    "Target folder does not exist any more" : "Каталог больше не существует",
    "Error when assembling chunks, status code {status}" : "Ошибка при сборке чанков, код ошибки {status}",
    "Actions" : "Действия",
    "Rename" : "Переименовать",
    "Copy" : "Копировать",
    "Choose target folder" : "Выберите каталога назначения",
    "Open" : "Открыть",
    "Disconnect storage" : "Отсоединить хранилище",
    "Unshare" : "Закрыть доступ",
    "Could not load info for file \"{file}\"" : "Не удаётся загрузить информацию для файла \"{file}\"",
    "Files" : "Файлы",
    "Details" : "Подробно",
    "Select" : "Выбрать",
    "Pending" : "Ожидается",
    "Unable to determine date" : "Невозможно определить дату",
    "This operation is forbidden" : "Операция запрещена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступен. Проверьте журналы событий или свяжитесь с администратором",
    "Could not move \"{file}\", target exists" : "Невозможно переместить файл «{file}», он уже существует в каталоге назначения",
    "Could not move \"{file}\"" : "Невозможно переместить файл «{file}»",
    "copy" : "копия",
    "Could not copy \"{file}\", target exists" : "Невозможно скопировать файл «{file}», он уже существует в каталоге назначения",
    "Could not copy \"{file}\"" : "Невозможно скопировать файл «{file}»",
    "Copied {origin} inside {destination}" : "{origin} скопирован в {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} и {nbfiles} других файлов скопированы в {destination}",
    "{newName} already exists" : "«{newName}» уже существует",
    "Could not rename \"{fileName}\", it does not exist any more" : "Невозможно переименовать «{fileName}», файл больше не существует",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя «{targetName}» уже используется в каталоге «{dir}». Выберите другое имя.",
    "Could not rename \"{fileName}\"" : "Невозможно переименовать «{fileName}»",
    "Could not create file \"{file}\"" : "Невозможно создать файл «{file}»",
    "Could not create file \"{file}\" because it already exists" : "Невозможно создать файл «{file}», он уже существует",
    "Could not create folder \"{dir}\" because it already exists" : "Невозможно создать каталог «{dir}», он уже существует",
    "Error deleting file \"{fileName}\"." : "Ошибка удаления файла «{fileName}».",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нет результатов поиска в других папках для {tag}{filter}{endtag}",
    "Name" : "Имя",
    "Size" : "Размер",
    "Modified" : "Изменён",
    "_%n folder_::_%n folders_" : ["%n каталог","%n каталога","%n каталогов","%n каталогов"],
    "_%n file_::_%n files_" : ["%n файл","%n файла","%n файлов","%n файлов"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["включая %n скрытый","включая %n скрытых","включая %n скрытых","включая %n скрытых"],
    "You don’t have permission to upload or create files here" : "У вас нет разрешений на создание или загрузку файлов в эту папку.",
    "_Uploading %n file_::_Uploading %n files_" : ["Выгружа%nется  файл","Выгружаются %n файла","Выгружаются %n файлов","Загружаются %n файлов"],
    "New" : "Новый",
    "Select file range" : "Выберите диапазон файлов",
    "{used} of {quota} used" : "использовано {used} из {quota}",
    "{used} used" : "использовано {used}",
    "\"{name}\" is an invalid file name." : "«{name}» — недопустимое имя файла.",
    "File name cannot be empty." : "Имя файла не может быть пустым.",
    "\"/\" is not allowed inside a file name." : "Символ «/» недопустим в имени файла.",
    "\"{name}\" is not an allowed filetype" : "«{name}» - недопустимый тип файла.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Хранилище {owner} переполнено, файлы больше не могут быть обновлены или синхронизированы!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше хранилище переполнено, файлы больше не могут быть обновлены или синхронизированы!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Хранилище {owner} практически заполнено ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше хранилище почти заполнено ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["соответствует '{filter}'","соответствуют '{filter}'","соответствуют '{filter}'","соответствуют '{filter}'"],
    "View in folder" : "Посмотреть в каталоге",
    "Copied!" : "Скопировано!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Копировать прямую ссылку (работает только для пользователей с правами доступа к этому файлу или каталогу)",
    "Path" : "Путь",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байт"],
    "Favorited" : "Избранное",
    "Favorite" : "Добавить в избранное",
    "You can only favorite a single file or folder at a time" : "Одновременно можно выбрать только один файл или папку",
    "New folder" : "Новый каталог",
    "Upload file" : "Загрузить файл",
    "Not favorited" : "Не избранное",
    "Remove from favorites" : "Удалить из избранных",
    "Add to favorites" : "Добавить в избранное",
    "An error occurred while trying to update the tags" : "Во время обновления тегов возникла ошибка",
    "Added to favorites" : "Добавлено в избранное",
    "Removed from favorites" : "Удалено из избранного",
    "You added {file} to your favorites" : "Вы добавили «{file}» в избранное",
    "You removed {file} from your favorites" : "Вы удалили «{file}» из избранного",
    "File changes" : "Изменения файлов",
    "Created by {user}" : "Создано {user}",
    "Changed by {user}" : "Изменено {user}",
    "Deleted by {user}" : "Удалено {user}",
    "Restored by {user}" : "Восстановлено {user}",
    "Renamed by {user}" : "Переименовано {user}",
    "Moved by {user}" : "Перемещено {user}",
    "\"remote user\"" : "«пользователь с другого сервера»",
    "You created {file}" : "Вы создали «{file}»",
    "You created an encrypted file in {file}" : "Вы создали зашифрованный файл в «{file}»",
    "{user} created {file}" : "{user} создал(а) «{file}»",
    "{user} created an encrypted file in {file}" : "{user} создал(а) зашифрованный файл в «{file}»",
    "{file} was created in a public folder" : "«{file}» создан в общедоступом каталоге",
    "You changed {file}" : "Вы изменили «{file}»",
    "You changed an encrypted file in {file}" : "Вы изменили зашифрованный файл в «{file}»",
    "{user} changed {file}" : "{user} изменил(а) «{file}»",
    "{user} changed an encrypted file in {file}" : "{user} изменил(а) зашифрованный файл в «{file}»",
    "You deleted {file}" : "Вы удалили «{file}»",
    "You deleted an encrypted file in {file}" : "Вы удалили зашифрованный файл в «{file}»",
    "{user} deleted {file}" : "{user} удалил(а) «{file}»",
    "{user} deleted an encrypted file in {file}" : " {user} удалил(а) зашифрованный файл в «{file}»",
    "You restored {file}" : "Вы восстановили «{file}»",
    "{user} restored {file}" : "{user} восстановил(а) «{file}»",
    "You renamed {oldfile} to {newfile}" : "Вы переименовали «{oldfile}» в «{newfile}»",
    "{user} renamed {oldfile} to {newfile}" : "{user} переименовал(а) «{oldfile}» в «{newfile}»",
    "You moved {oldfile} to {newfile}" : "Вы переместили «{oldfile}» в «{newfile}»",
    "{user} moved {oldfile} to {newfile}" : "{user} переместил(а) «{oldfile}» в «{newfile}»",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл добавлен в <strong>избранное</strong> или удалён оттуда",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Файл или каталог <strong>изменён</strong> или <strong>переименован</strong>",
    "A new file or folder has been <strong>created</strong>" : "<strong>Создан</strong> файл или каталог",
    "A file or folder has been <strong>deleted</strong>" : "Файл или каталог <strong>удалён</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничить уведомления о создании и изменении ваших <strong>избранных файлов</strong> <em>(отображать только в приложении события)</em>",
    "A file or folder has been <strong>restored</strong>" : "Файл или каталог <strong>восстановлен</strong>",
    "Unlimited" : "Неограничено",
    "Upload (max. %s)" : "Загрузка (максимум %s)",
    "File Management" : "Управление файлами",
    "%s used" : "%s использовано",
    "%s%% of %s used" : "использовано %s%% из %s",
    "%1$s of %2$s used" : "использовано %1$s из %2$s ",
    "Settings" : "Настройки",
    "Show hidden files" : "Показывать скрытые файлы",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Используйте этот адрес для <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">доступа к вашим файлам через WebDAV</a>",
    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
    "No files in here" : "Здесь нет файлов",
    "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
    "No entries found in this folder" : "В этом каталоге ничего не найдено",
    "Select all" : "Выбрать все",
    "Upload too large" : "Файл слишком велик",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь загрузить, превышают лимит максимального размера на этом сервере.",
    "No favorites yet" : "В избранное ещё ничего не добавлено ",
    "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
    "Tags" : "Метки",
    "Deleted files" : "Корзина",
    "Shares" : "Общие ресурсы",
    "Shared with others" : "Доступные для других",
    "Shared with you" : "Доступные для вас",
    "Shared by link" : "Доступные по ссылке",
    "Deleted shares" : "Удаленные общие ресурсы",
    "Text file" : "Текстовый файл",
    "New text file.txt" : "Новый текстовый файл.txt",
    "Target folder" : "Целевой каталог",
    "File handling" : "Управление файлами",
    "Maximum upload size" : "Максимальный размер загружаемого файла",
    "max. possible: " : "макс. возможно: ",
    "Save" : "Сохранить",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "В режиме PHP-FPM применение изменений может занять до 5 минут.",
    "Missing permissions to edit from here." : "Отсутствуют права на внесение здесь изменений.",
    "%s of %s used" : "использовано %s из %s",
    "Cancel upload" : "Отменить загрузку",
    "%1$s%% of %2$s used" : "использовано %1$s%% из %2$s"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ru.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Хранилище временно недоступно",
    "Storage invalid" : "Хранилище неисправно",
    "Unknown error" : "Неизвестная ошибка",
    "All files" : "Все файлы",
    "Recent" : "Недавно изменённые",
    "Favorites" : "Избранные",
    "File could not be found" : "Невозможно найти файл",
    "Move or copy" : "Переместить или копировать",
    "Download" : "Скачать",
    "Delete" : "Удалить",
    "Home" : "Главная",
    "Close" : "Закрыть",
    "Could not create folder \"{dir}\"" : "Невозможно создать каталог «{dir}»",
    "This will stop your current uploads." : "Это действие остановит активные сеансы передачи файлов на сервер. ",
    "Upload cancelled." : "Выгрузка отменена.",
    "Processing files …" : "Обработка файлов…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Невозможно загрузить «{filename}», так как это либо каталог, либо файл нулевого размера",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Недостаточно свободного места, вы передаёте на сервер {size1}, но доступно только {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Целевой каталог «{dir}» более не существует",
    "Not enough free space" : "Недостаточно свободного места",
    "An unknown error has occurred" : "Произошла неизвестная ошибка",
    "Uploading …" : "Загрузка…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} из {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Загрузка этого элемента не поддерживается",
    "Target folder does not exist any more" : "Каталог больше не существует",
    "Error when assembling chunks, status code {status}" : "Ошибка при сборке чанков, код ошибки {status}",
    "Actions" : "Действия",
    "Rename" : "Переименовать",
    "Copy" : "Копировать",
    "Choose target folder" : "Выберите каталога назначения",
    "Open" : "Открыть",
    "Delete file" : "Удалить файл",
    "Delete folder" : "Удалить каталог",
    "Disconnect storage" : "Отсоединить хранилище",
    "Unshare" : "Закрыть доступ",
    "Could not load info for file \"{file}\"" : "Не удаётся загрузить информацию для файла \"{file}\"",
    "Files" : "Файлы",
    "Details" : "Подробно",
    "Select" : "Выбрать",
    "Pending" : "Ожидается",
    "Unable to determine date" : "Невозможно определить дату",
    "This operation is forbidden" : "Операция запрещена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступен. Проверьте журналы событий или свяжитесь с администратором",
    "Could not move \"{file}\", target exists" : "Невозможно переместить файл «{file}», он уже существует в каталоге назначения",
    "Could not move \"{file}\"" : "Невозможно переместить файл «{file}»",
    "copy" : "копия",
    "Could not copy \"{file}\", target exists" : "Невозможно скопировать файл «{file}», он уже существует в каталоге назначения",
    "Could not copy \"{file}\"" : "Невозможно скопировать файл «{file}»",
    "Copied {origin} inside {destination}" : "{origin} скопирован в {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} и {nbfiles} других файлов скопированы в {destination}",
    "{newName} already exists" : "«{newName}» уже существует",
    "Could not rename \"{fileName}\", it does not exist any more" : "Невозможно переименовать «{fileName}», файл больше не существует",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя «{targetName}» уже используется в каталоге «{dir}». Выберите другое имя.",
    "Could not rename \"{fileName}\"" : "Невозможно переименовать «{fileName}»",
    "Could not create file \"{file}\"" : "Невозможно создать файл «{file}»",
    "Could not create file \"{file}\" because it already exists" : "Невозможно создать файл «{file}», он уже существует",
    "Could not create folder \"{dir}\" because it already exists" : "Невозможно создать каталог «{dir}», он уже существует",
    "Error deleting file \"{fileName}\"." : "Ошибка удаления файла «{fileName}».",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нет результатов поиска в других папках для {tag}{filter}{endtag}",
    "Name" : "Имя",
    "Size" : "Размер",
    "Modified" : "Изменён",
    "_%n folder_::_%n folders_" : ["%n каталог","%n каталога","%n каталогов","%n каталогов"],
    "_%n file_::_%n files_" : ["%n файл","%n файла","%n файлов","%n файлов"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["включая %n скрытый","включая %n скрытых","включая %n скрытых","включая %n скрытых"],
    "You don’t have permission to upload or create files here" : "У вас нет разрешений на создание или загрузку файлов в эту папку.",
    "_Uploading %n file_::_Uploading %n files_" : ["Выгружа%nется  файл","Выгружаются %n файла","Выгружаются %n файлов","Загружаются %n файлов"],
    "New" : "Новый",
    "Select file range" : "Выбор диапазона файлов",
    "{used} of {quota} used" : "использовано {used} из {quota}",
    "{used} used" : "использовано {used}",
    "\"{name}\" is an invalid file name." : "«{name}» — недопустимое имя файла.",
    "File name cannot be empty." : "Имя файла не может быть пустым.",
    "\"/\" is not allowed inside a file name." : "Символ «/» недопустим в имени файла.",
    "\"{name}\" is not an allowed filetype" : "«{name}» - недопустимый тип файла.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Хранилище {owner} переполнено, файлы больше не могут быть обновлены или синхронизированы!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше хранилище переполнено, файлы больше не могут быть обновлены или синхронизированы.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Хранилище {owner} практически заполнено ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше хранилище почти заполнено ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["соответствует '{filter}'","соответствуют '{filter}'","соответствуют '{filter}'","соответствуют '{filter}'"],
    "View in folder" : "Посмотреть в каталоге",
    "Copied!" : "Скопировано!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Копировать прямую ссылку (работает только для пользователей с правами доступа к этому файлу или каталогу)",
    "Path" : "Путь",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байт"],
    "Favorited" : "Избранное",
    "Favorite" : "Добавить в избранное",
    "You can only favorite a single file or folder at a time" : "Одновременно можно выбрать только один файл или папку",
    "New folder" : "Новый каталог",
    "Upload file" : "Загрузить файл",
    "Not favorited" : "Не избранное",
    "Remove from favorites" : "Удалить из избранных",
    "Add to favorites" : "Добавить в избранное",
    "An error occurred while trying to update the tags" : "Во время обновления тегов возникла ошибка",
    "Added to favorites" : "Добавлено в избранное",
    "Removed from favorites" : "Удалено из избранного",
    "You added {file} to your favorites" : "Вы добавили «{file}» в избранное",
    "You removed {file} from your favorites" : "Вы удалили «{file}» из избранного",
    "File changes" : "Изменения файлов",
    "Created by {user}" : "Создано {user}",
    "Changed by {user}" : "Изменено {user}",
    "Deleted by {user}" : "Удалено {user}",
    "Restored by {user}" : "Восстановлено {user}",
    "Renamed by {user}" : "Переименовано {user}",
    "Moved by {user}" : "Перемещено {user}",
    "\"remote user\"" : "«пользователь с другого сервера»",
    "You created {file}" : "Вы создали «{file}»",
    "You created an encrypted file in {file}" : "Вы создали зашифрованный файл в «{file}»",
    "{user} created {file}" : "{user} создал(а) «{file}»",
    "{user} created an encrypted file in {file}" : "{user} создал(а) зашифрованный файл в «{file}»",
    "{file} was created in a public folder" : "«{file}» создан в общедоступом каталоге",
    "You changed {file}" : "Вы изменили «{file}»",
    "You changed an encrypted file in {file}" : "Вы изменили зашифрованный файл в «{file}»",
    "{user} changed {file}" : "{user} изменил(а) «{file}»",
    "{user} changed an encrypted file in {file}" : "{user} изменил(а) зашифрованный файл в «{file}»",
    "You deleted {file}" : "Вы удалили «{file}»",
    "You deleted an encrypted file in {file}" : "Вы удалили зашифрованный файл в «{file}»",
    "{user} deleted {file}" : "{user} удалил(а) «{file}»",
    "{user} deleted an encrypted file in {file}" : " {user} удалил(а) зашифрованный файл в «{file}»",
    "You restored {file}" : "Вы восстановили «{file}»",
    "{user} restored {file}" : "{user} восстановил(а) «{file}»",
    "You renamed {oldfile} to {newfile}" : "Вы переименовали «{oldfile}» в «{newfile}»",
    "{user} renamed {oldfile} to {newfile}" : "{user} переименовал(а) «{oldfile}» в «{newfile}»",
    "You moved {oldfile} to {newfile}" : "Вы переместили «{oldfile}» в «{newfile}»",
    "{user} moved {oldfile} to {newfile}" : "{user} переместил(а) «{oldfile}» в «{newfile}»",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл добавлен в <strong>избранное</strong> или удалён оттуда",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Файл или каталог <strong>изменён</strong> или <strong>переименован</strong>",
    "A new file or folder has been <strong>created</strong>" : "<strong>Создан</strong> файл или каталог",
    "A file or folder has been <strong>deleted</strong>" : "Файл или каталог <strong>удалён</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничить уведомления о создании и изменении ваших <strong>избранных файлов</strong> <em>(отображать только в приложении события)</em>",
    "A file or folder has been <strong>restored</strong>" : "Файл или каталог <strong>восстановлен</strong>",
    "Unlimited" : "Неограничено",
    "Upload (max. %s)" : "Загрузка (максимум %s)",
    "File Management" : "Управление файлами",
    "%s used" : "%s использовано",
    "%s%% of %s used" : "использовано %s%% из %s",
    "%1$s of %2$s used" : "использовано %1$s из %2$s ",
    "Settings" : "Настройки",
    "Show hidden files" : "Показывать скрытые файлы",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Используйте этот адрес для <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">доступа к своим файлам по протоколу WebDAV</a>",
    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
    "No files in here" : "Здесь нет файлов",
    "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
    "No entries found in this folder" : "В этом каталоге ничего не найдено",
    "Select all" : "Выбрать все",
    "Upload too large" : "Файл слишком велик",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь загрузить, превышают лимит максимального размера на этом сервере.",
    "No favorites yet" : "В избранное ещё ничего не добавлено ",
    "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
    "Tags" : "Метки",
    "Deleted files" : "Корзина",
    "Shares" : "Общие ресурсы",
    "Shared with others" : "Доступные для других",
    "Shared with you" : "Доступные для вас",
    "Shared by link" : "Доступные по ссылке",
    "Deleted shares" : "Удаленные общие ресурсы",
    "Text file" : "Текстовый файл",
    "New text file.txt" : "Новый текстовый файл.txt",
    "File handling" : "Управление файлами",
    "Maximum upload size" : "Максимальный размер загружаемого файла",
    "max. possible: " : "макс. возможно: ",
    "Save" : "Сохранить",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "В режиме PHP-FPM применение изменений может занять до 5 минут.",
    "Missing permissions to edit from here." : "Отсутствуют права на внесение здесь изменений.",
    "Cancel upload" : "Отменить загрузку",
    "%s of %s used" : "использовано %s из %s",
    "%1$s%% of %2$s used" : "использовано %1$s%% из %2$s"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
